@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Colin Ian King 2015-2020
+ * Copyright (C) Colin Ian King 2015-2021
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -808,7 +808,6 @@ static int show_pages(
 		(void)memset(pagemap_info_buf, 0, sz);
 
 		if (idx >= (index_t)g.mem_info.npages) {
-			addr = 0;
 			map = NULL;
 		} else {
 			addr = g.mem_info.pages[idx].addr;
@@ -1293,8 +1292,8 @@ int main(int argc, char **argv)
 		if ((g.view == VIEW_PAGE) && g.auto_zoom) {
 			const int32_t window_pages = p->xmax * p->ymax;
 
-			zoom = (g.mem_info.npages + window_pages - 1) /
-				window_pages;
+			zoom = (window_pages == 0) ? 1 :
+				(g.mem_info.npages + window_pages - 1) / window_pages;
 			zoom = MINIMUM(MAX_ZOOM, zoom);
 			zoom = MAXIMUM(MIN_ZOOM, zoom);
 		}
